function [A1, A2, B1m,B1l, B2m,B2l] = ABdiff_MF12(para_str, mature) 
% ABdiff_MF1 calculates A and B with difference equations
% USAGE: [A1, A2, B1m,B1l, B2m,B2l] = ABdiff_MF1(para_str, mature) 
% INPUTS:   APpara_str: a structure of parameters
%           mature:     a structure containing mature.exact and
%                       mature.error
% OUTPUTS:  A1:         3*1  vector
%           A2:         Ne*1 vector
%           B1m:        3*24 matrix
%           B2m:        Ne*24matrix
%           B1l:        3*3  matrix
%           B2l:        Ne*3 matrix
%LAST UPDATE 4/6/2010

N = 3;
nN = max(max(mature.exact),max(mature.error));
[muQ, rhoQ, rho,sig, delta1, delta0] = para_str2ind_MF12(para_str);
NN = length(rho);

A_bar_temp = -delta0;  %initial value for A_bar and B_bar
B_bar_temp = -delta1;

A = zeros(nN,1);
B = zeros(NN,nN);

A(1) = -A_bar_temp;  %A1 and B1
B(:,1) = -B_bar_temp;

for i = 2:nN
    %A_bar_temp = A_bar_temp+B_bar_temp'*(-sig*lam0)+1/2*B_bar_temp'*(sig*sig')*B_bar_temp-delta0;
    A_bar_temp = A_bar_temp+B_bar_temp'*muQ+1/2*B_bar_temp'*(sig*sig')*B_bar_temp-delta0;   
    %B_bar_temp = (rho-sig*lam1)'* B_bar_temp - delta1;
    B_bar_temp = rhoQ'* B_bar_temp - delta1;
    A(i)   = -A_bar_temp/i;
    B(:,i) = -B_bar_temp/i;      
end                                                    

B = B';

A1 = A(mature.exact);
A2 = A(mature.error);
B1 = B(mature.exact,:);
B2 = B(mature.error,:); 

B1m = B1(:,1:end-N);
B1l = B1(:,end-N+1:end);
B2m = B2(:,1:end-N);
B2l = B2(:,end-N+1:end);